@@ -36,9 +36,21 @@
 #include <unistd.h>
 #include <curses.h>
 
+#ifdef HAVE_NETAX25_AX25_H
 #include <netax25/ax25.h>
+#else
+#include <netax25/kernel_ax25.h>
+#endif
+#ifdef HAVE_NETROM_NETROM_H
 #include <netrom/netrom.h>
+#else
+#include <netax25/kernel_netrom.h>
+#endif
+#ifdef HAVE_NETROSE_ROSE_H
 #include <netrose/rose.h>
+#else
+#include <netax25/kernel_rose.h>
+#endif
 
 #include <netax25/axlib.h>
 #include <netax25/axconfig.h>
@@ -301,7 +313,7 @@ static int connect_to(char *address[])
 	break;
 
     case AF_AX25:
-	if (ax25_aton_arglist(address, &sockaddr.ax25) == -1) {
+	if (ax25_aton_arglist((const char**)address, &sockaddr.ax25) == -1) {
 	    close(fd);
 	    return (-1);
 	}
